/* EditRun - March 26th, 2001
**
**      Copyright (c) 1997-2001 by Gregory Braun. All rights reserved.
**
**      This function opens and displays a dialog box allowing the user
**      to edit a specific Run registry entry.
**
**      Called:     w   = window handle of the parent.
**                  run = a pointer to the RUN data structure.
**
**      Returns:    TRUE upon success, or FALSE if an error exists,
**                  or the user pressed the [Cancel] key.
*/

#include "AppPaths.h"


#define MISSING_NAME        "Startup title missing.\r\r" \
                            "Startup registry values require a startup title.\r" \
                            "Please specify a title for this registry entry."

#define MISSING_PATH        "Program command missing.\r\r" \
                            "Startup registry values require a program command.\r" \
                            "Please specify a program for this registry entry."


static RUN                  tmp;        // just in case the user cancels.


static BOOL CALLBACK        dialog      (HWND dlg,UINT msg,WPARAM wp,LPARAM lp);

static BOOL                 initiate    (HWND dlg,LPRUN tmp);
static BOOL                 verify      (HWND dlg,LPRUN tmp);

static BOOL                 path        (HWND dlg,LPRUN tmp);

extern BOOL far EditRun (HWND w,LPRUN run)
{
    tmp = *run;

    if (!DialogBoxParam (applet,(LPCSTR) RUN_DLG,w,(DLGPROC) dialog,(LPARAM) &tmp))
        return (FALSE);

    *run = tmp;

    return (TRUE);
}

static BOOL CALLBACK dialog (HWND dlg,UINT msg,WPARAM wp,LPARAM lp)
{
    auto int    item    = LOWORD (wp);

    switch (msg) {

        case WM_INITDIALOG :
             return (initiate (dlg,(LPRUN) lp));
             break;

        case WM_HELP :
             HelpTip (dlg,((LPHELPINFO) lp)->iCtrlId);
             break;

        case WM_COMMAND :

             switch (item) {

                case RUN_PATH_BTN :
                     path (dlg,&tmp);
                     break;

                case RUN_HELP_BTN :
                     HelpTopic (dlg,RUN_DLG);
                     break;

                case IDOK :
                     if (verify (dlg,&tmp))
                         EndDialog (dlg,TRUE);
                     return (TRUE);
                     break;

                case IDCANCEL :
                     EndDialog (dlg,FALSE);
                     return (TRUE);
                     break;
                     }

             break;
             }


     return (FALSE);
}

static BOOL initiate (HWND dlg,LPRUN tmp)
{
    auto HWND   ctl = GetDlgItem (dlg,RUN_ICON_PIC);
    auto HICON  ico = ExtractIcon (applet,tmp->path,NIL);

    if ((DWORD) ico < 33)
        ico = LoadIcon (applet,(LPCSTR) WINDOWS_ICON);

    SetDlgIcon (dlg,APPLICATION_ICON);

    Static_SetIcon (ctl,ico);

    SetDlgItemSize (dlg,RUN_NAME_TXT,PSTRING);
    SetDlgItemText (dlg,RUN_NAME_TXT,tmp->name);

    SetDlgItemSize (dlg,RUN_PATH_TXT,RUN_MAX);
    SetDlgItemText (dlg,RUN_PATH_TXT,tmp->path);

    return (TRUE);
}

static BOOL verify (HWND dlg,LPRUN tmp)
{
    GetDlgItemText (dlg,RUN_NAME_TXT,tmp->name,PSTRING);
    GetDlgItemText (dlg,RUN_PATH_TXT,tmp->path,RUN_MAX);

    if (!*tmp->name) {
        Message (dlg,NULL,MISSING_NAME);
        return (SetDFocus (dlg,RUN_NAME_TXT));
        }

    if (!*tmp->path) {
        Message (dlg,NULL,MISSING_PATH);
        return (SetDFocus (dlg,RUN_PATH_TXT));
        }

    return (TRUE);
}

static BOOL path (HWND dlg,LPRUN tmp)
{
    auto HWND   ctl = GetDlgItem (dlg,RUN_ICON_PIC);
    auto HICON  ico = ExtractIcon (applet,tmp->path,NIL);

    GetDlgItemText (dlg,RUN_PATH_TXT,tmp->path,PSTRING);

    if (!PickApp (dlg,tmp->path))
        return (FALSE);

    if (lstrlen (tmp->path) >= RUN_MAX)
        tmp->path[RUN_MAX] = EOS;

    SetDlgItemText (dlg,RUN_PATH_TXT,tmp->path);

    ico = ExtractIcon (applet,tmp->path,NIL);

    if ((DWORD) ico < 33)
        ico = LoadIcon (applet,(LPCSTR) WINDOWS_ICON);

    Static_SetIcon (ctl,ico);

    return (TRUE);
}

/* end of EditRun.c - written by Gregory Braun */
